@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: MIDI pitches for guitar chord voicings
 
-our $VERSION = '0.0300';
+our $VERSION = '0.0301';
 
 use strict;
 use warnings;
@@ -67,7 +67,7 @@ sub transform {
       @notes = map { $_ + $diff } @$pitches;
     }
     else {
-        for my $pitches ($self->chords->{ 'C' . $chord_name }->@*) {
+        for my $pitches (@{ $self->chords->{ 'C' . $chord_name } }) {
             my $diff = $target - _lowest_c($pitches);
             push @notes, [ map { $_ + $diff } @$pitches ];
         }
@@ -122,7 +122,7 @@ MIDI::Chord::Guitar - MIDI pitches for guitar chord voicings
 
 =head1 VERSION
 
-version 0.0300
+version 0.0301
 
 =head1 SYNOPSIS
 
